@@ -118,13 +118,18 @@ class DiegoOperator(PythonOperator):
 
     def execute(self, context):
         df = super().execute(context)
+
+        temp_file_path = f"cortex-data-lakehouse-metastore-development/temp-files-diego/{self.task_id}/{self.cube_id}/{str(hash(datetime.utcnow().isoformat()))}"
+
         if isinstance(df, collections.Iterator):
-            for df_part in df:
-                execution_ids = self.__execute_df(df=df_part)
+            for part_number, df_part in enumerate(df):
+                self.__execute_df(df=df_part, part_number=part_number, path=f"s3://{temp_file_path}")
         else:
-            execution_ids = self.__execute_df(df=df)
-        if not self.ignore_empty_dataframe:
+            self.__execute_df(df=df, part_number=1, path=f"s3://{temp_file_path}")
+
+        response = self.send_file_path_to_diego(temp_file_path)
+
+        if not self.ignore_empty_dataframe and not response.json().get("replyId"):
             raise ValueError('There were no dataframes written to Diego. Please check if your dataframes are empty')
 
         context['task_instance'].xcom_push(key='platform_url', value=self.platform_url)
-        context['task_instance'].xcom_push(key='execution_ids', value=execution_ids)
